==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/FunnelDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelDataContextDescription } from "./FunnelDataContextDescription";
/**
 * @hidden
 */
var FunnelDataContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FunnelDataContextDescriptionMetadata, _super);
    function FunnelDataContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelDataContextDescriptionMetadata.b = function (a) {
        if (FunnelDataContextDescriptionMetadata.a == null) {
            FunnelDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelDataContextDescriptionMetadata.c(FunnelDataContextDescriptionMetadata.a);
        }
        if (a.j(FunnelDataContextDescriptionMetadata.a)) {
            return;
        }
        a.y(FunnelDataContextDescriptionMetadata.a);
    };
    FunnelDataContextDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("Index", "Number:int");
    };
    FunnelDataContextDescriptionMetadata.d = function (a) {
        FunnelDataContextDescriptionMetadata.b(a);
        a.aa("FunnelDataContext", function () { return new FunnelDataContextDescription(); });
        a.z("FunnelDataContext", FunnelDataContextDescriptionMetadata.a);
    };
    FunnelDataContextDescriptionMetadata.$t = markType(FunnelDataContextDescriptionMetadata, 'FunnelDataContextDescriptionMetadata');
    FunnelDataContextDescriptionMetadata.a = null;
    return FunnelDataContextDescriptionMetadata;
}(Base));
export { FunnelDataContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/FunnelDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelDataContextDescription } from "./FunnelDataContextDescription";
/**
 * @hidden
 */
var FunnelDataContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FunnelDataContextDescriptionMetadata, _super);
    function FunnelDataContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelDataContextDescriptionMetadata.b = function (a) {
        if (FunnelDataContextDescriptionMetadata.a == null) {
            FunnelDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelDataContextDescriptionMetadata.c(FunnelDataContextDescriptionMetadata.a);
        }
        if (a.k(FunnelDataContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(FunnelDataContextDescriptionMetadata.a);
    };
    FunnelDataContextDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("Index", "Number:int");
    };
    FunnelDataContextDescriptionMetadata.d = function (a) {
        FunnelDataContextDescriptionMetadata.b(a);
        a.ac("FunnelDataContext", function () { return new FunnelDataContextDescription(); });
        a.ab("FunnelDataContext", FunnelDataContextDescriptionMetadata.a);
    };
    FunnelDataContextDescriptionMetadata.$t = markType(FunnelDataContextDescriptionMetadata, 'FunnelDataContextDescriptionMetadata');
    FunnelDataContextDescriptionMetadata.a = null;
    return FunnelDataContextDescriptionMetadata;
}(Base));
export { FunnelDataContextDescriptionMetadata };
